@@ -25,7 +25,6 @@ import (
 	ConfigManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
 	abrecovery "github.com/linuxdeepin/go-dbus-factory/system/com.deepin.abrecovery"
 	accounts "github.com/linuxdeepin/go-dbus-factory/system/org.deepin.dde.accounts1"
-	apps "github.com/linuxdeepin/go-dbus-factory/system/org.deepin.dde.apps1"
 	power "github.com/linuxdeepin/go-dbus-factory/system/org.deepin.dde.power1"
 	ofdbus "github.com/linuxdeepin/go-dbus-factory/system/org.freedesktop.dbus"
 	login1 "github.com/linuxdeepin/go-dbus-factory/system/org.freedesktop.login1"
@@ -71,7 +70,6 @@ type Manager struct {
 	inhibitFd        dbus.UnixFD
 	updateSourceOnce bool
 
-	apps       apps.Apps
 	sysPower   power.Power
 	signalLoop *dbusutil.SignalLoop
 
@@ -137,7 +135,6 @@ func NewManager(service *dbusutil.Service, updateApi system.System, c *config.Co
 		loginManager:         login1.NewManager(service.Conn()),
 		sysDBusDaemon:        ofdbus.NewDBus(service.Conn()),
 		signalLoop:           dbusutil.NewSignalLoop(service.Conn(), 10),
-		apps:                 apps.NewApps(service.Conn()),
 		systemd:              systemd1.NewManager(service.Conn()),
 		sysPower:             power.NewPower(service.Conn()),
 		abObj:                abrecovery.NewABRecovery(service.Conn()),
@@ -463,17 +460,6 @@ func (m *Manager) removePackage(sender dbus.Sender, jobName string, packages str
 		return nil, fmt.Errorf("invalid packages arguments %q : %v", packages, err)
 	}
 
-	if len(pkgs) == 1 {
-		desktopFiles := listPackageDesktopFiles(pkgs[0])
-		if len(desktopFiles) > 0 {
-			err = m.apps.LaunchedRecorder().UninstallHints(0, desktopFiles)
-			if err != nil {
-				logger.Warningf("call UninstallHints(desktopFiles: %v) error: %v",
-					desktopFiles, err)
-			}
-		}
-	}
-
 	environ, err := makeEnvironWithSender(m, sender)
 	if err != nil {
 		return nil, err
@@ -536,7 +522,7 @@ func (m *Manager) cleanArchives(needNotify bool) (*Job, error) {
 		string(system.EndStatus): func() error {
 			// 清理完成的通知
 			msg := gettext.Tr("Package cache wiped")
-			go m.sendNotify(updateNotifyShow, 0, "deepin-appstore", "", msg, nil, nil, system.NotifyExpireTimeoutDefault)
+			go m.sendNotify(updateNotifyShow, 0, "", "", msg, nil, nil, system.NotifyExpireTimeoutDefault)
 			return nil
 		},
 	})
