@@ -77,14 +77,11 @@ func (m *Manager) checkUpgrade(sender dbus.Sender, checkMode system.UpdateType,
 	if err != nil {
 		return "", err
 	}
-	job.option[dut.PostCheck.String()] = "--check-succeed" // TODO 还有--check-failed 的情况需要处理
-
-	job.option["--meta-cfg"] = system.DutOnlineMetaConfPath
-
+	if isExist {
+		return job.getPath(), nil
+	}
 	if checkOrder == firstCheck {
-		job.option["--stage1"] = ""
-	} else {
-		job.option["--stage2"] = ""
+		job.option[dut.OptionFirstCheck] = "1"
 	}
 
 	uuid := getRebootCheckJobUUID()
@@ -117,7 +114,14 @@ func (m *Manager) checkUpgrade(sender dbus.Sender, checkMode system.UpdateType,
 			go func() {
 				m.inhibitAutoQuitCountAdd()
 				defer m.inhibitAutoQuitCountSub()
-				m.updatePlatform.PostStatusMessage(fmt.Sprintf("%v postcheck error: %v", checkOrder.JobType(), job.Description))
+
+				m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+					Type:           "error",
+					UpdateType:     checkOrder.JobType(),
+					JobDescription: job.Description,
+					Detail:         fmt.Sprintf("%v postcheck error: %v", checkOrder.JobType(), job.Description),
+				})
+
 				m.reportLog(upgradeStatusReport, false, job.Description)
 			}()
 			inhibit(false)
@@ -156,9 +160,6 @@ func (m *Manager) checkUpgrade(sender dbus.Sender, checkMode system.UpdateType,
 			return nil
 		},
 	})
-	if isExist {
-		return job.getPath(), nil
-	}
 
 	if err = m.jobManager.addJob(job); err != nil {
 		return "", err
