@@ -31,9 +31,45 @@ import (
 	"github.com/linuxdeepin/go-lib/utils"
 )
 
-const (
-	DEEPIN_IMMUTABLE_CTL = "/usr/sbin/deepin-immutable-ctl"
-)
+func (m *Manager) retryDistUpgrade(upgradeJob *Job, needBackup bool) error {
+	if upgradeJob == nil {
+		return errors.New("upgrade job is nil")
+	}
+	m.do.Lock()
+	defer m.do.Unlock()
+
+	backupJob := m.jobManager.findJobByType(system.BackupJobType, nil)
+	// Handle existing backup job
+	if backupJob != nil {
+		if !backupJob.HasStatus(system.FailedStatus) {
+			return errors.New("backup job status is not failed")
+		}
+
+		if needBackup {
+			// Retry backup job
+			if err := m.jobManager.MarkStart(backupJob.Id); err != nil {
+				logger.Warningf("retryDistUpgrade: failed to mark start backup job: %v", err)
+				return fmt.Errorf("failed to start backup job: %w", err)
+			}
+			return nil
+		}
+
+		// Clean backup job when backup is not needed
+		if err := m.jobManager.CleanJob(backupJob.Id); err != nil {
+			logger.Warningf("retryDistUpgrade: failed to clean backup job: %v", err)
+			return fmt.Errorf("failed to clean backup job: %w", err)
+		}
+	} else {
+		logger.Debug("backup job not found")
+	}
+
+	// Start upgrade job
+	if err := m.jobManager.MarkStart(upgradeJob.Id); err != nil {
+		logger.Warningf("retryDistUpgrade: failed to mark start upgrade job: %v", err)
+		return fmt.Errorf("failed to start upgrade job: %w", err)
+	}
+	return nil
+}
 
 func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType, needBackup bool) (job dbus.ObjectPath, busErr *dbus.Error) {
 	// 创建job，但是不添加到任务队列中
@@ -52,11 +88,16 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 	}
 	upgradeJob, createJobErr = m.distUpgrade(sender, mode, false, false)
 	if createJobErr != nil {
-		if !errors.Is(createJobErr, JobExistError) {
-			return "/", dbusutil.ToError(createJobErr)
-		} else {
+		if errors.Is(createJobErr, JobExistError) {
+			// job exist, retry dist upgrade
+			err := m.retryDistUpgrade(upgradeJob, needBackup)
+			if err != nil {
+				logger.Warningf("DistUpgradePartly: retry upgrade job failed: %v", err)
+				return "/", dbusutil.ToError(err)
+			}
 			return upgradeJob.getPath(), nil
 		}
+		return "/", dbusutil.ToError(createJobErr)
 	}
 	var inhibitFd dbus.UnixFD = -1
 	why := Tr("Backing up and installing updates...")
@@ -125,8 +166,8 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 	m.inhibitAutoQuitCountAdd() // 开始备份前add，结束备份后sub(无论是否成功)
 	var isExist bool
 	var backupJob *Job
-	if needBackup && system.NormalFileExists(DEEPIN_IMMUTABLE_CTL) {
-		isExist, backupJob, err = m.jobManager.CreateJob("", system.BackupType, nil, nil, nil)
+	if needBackup && system.NormalFileExists(system.DeepinImmutableCtlPath) {
+		isExist, backupJob, err = m.jobManager.CreateJob("", system.BackupJobType, nil, nil, nil)
 		if isExist {
 			return "", dbusutil.ToError(JobExistError)
 		}
@@ -143,6 +184,8 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 				}
 				inhibit(true)
 				m.statusManager.SetABStatus(mode, system.BackingUp, system.NoABError)
+				// 设置UpdateStatus为WaitRunUpgrade，隐藏更新并关机/重启按钮
+				m.statusManager.SetUpdateStatus(mode, system.WaitRunUpgrade)
 				return nil
 			},
 			string(system.SucceedStatus): func() error {
@@ -152,14 +195,18 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 			},
 			string(system.FailedStatus): func() error {
 				m.statusManager.SetABStatus(mode, system.BackupFailed, system.OtherError)
+				// 备份失败时重置UpdateStatus为CanUpgrade，让用户可以重新操作
+				m.statusManager.SetUpdateStatus(mode, system.CanUpgrade)
 				inhibit(false)
 				msg := gettext.Tr("Backup failed!")
 				action := []string{"backup", gettext.Tr("Back Up Again"), "continue", gettext.Tr("Proceed to Update")}
 				hints := map[string]dbus.Variant{
+					// Backup and continue dist upgrade
 					"x-deepin-action-backup": dbus.MakeVariant(
-						fmt.Sprintf("dbus-send,--system,--print-reply,--dest=com.deepin.lastore,/com/deepin/lastore,com.deepin.lastore.Manager.DistUpgradePartly,uint64:%v,boolean:%v", mode, true)),
+						buildDistUpgradePartlyCommand(mode, true)),
+					// Continue dist upgrade without backup
 					"x-deepin-action-continue": dbus.MakeVariant(
-						fmt.Sprintf("dbus-send,--system,--print-reply,--dest=com.deepin.lastore,/com/deepin/lastore,com.deepin.lastore.Manager.DistUpgradePartly,uint64:%v,boolean:%v", mode, false))}
+						buildDistUpgradePartlyCommand(mode, false))}
 				go m.sendNotify(updateNotifyShowOptional, 0, "preferences-system", "", msg, action, hints, system.NotifyExpireTimeoutDefault)
 				return nil
 			},
@@ -198,6 +245,25 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 	return upgradeJob.getPath(), nil
 }
 
+// buildDistUpgradePartlyCommand builds a dbus-send command to invoke the DistUpgradePartly method
+func buildDistUpgradePartlyCommand(mode system.UpdateType, needBackup bool) string {
+	const methodName = "DistUpgradePartly"
+
+	// Build dbus-send command with proper arguments
+	args := []string{
+		"dbus-send",
+		"--system",
+		"--print-reply",
+		fmt.Sprintf("--dest=%s", dbusServiceName),
+		dbusObjectPath,
+		fmt.Sprintf("%s.%s", dbusInterfaceManager, methodName),
+		fmt.Sprintf("uint64:%v", mode),
+		fmt.Sprintf("boolean:%v", needBackup),
+	}
+
+	return strings.Join(args, ",")
+}
+
 // distUpgrade needAdd true: 返回的job已经被add到jobManager中；false: 返回的job需要被调用者add
 func (m *Manager) distUpgrade(sender dbus.Sender, mode system.UpdateType, needAdd bool, needChangeGrub bool) (*Job, error) {
 	m.checkDpkgCapabilityOnce.Do(func() {
@@ -290,21 +356,33 @@ func (m *Manager) distUpgrade(sender dbus.Sender, mode system.UpdateType, needAd
 		startJob.setPreHooks(map[string]func() error{
 			string(system.RunningStatus): func() error {
 				// 防止还在检查更新的时候，就生成了meta文件，此时meta文件可能不准
+				var err error
 				uuid, err = m.prepareAptCheck(mode)
 				if err != nil {
 					logger.Warning(err)
-					m.updatePlatform.PostStatusMessage(fmt.Sprintf("%v gen dut meta failed, detail is: %v", mode.JobType(), err.Error()))
+
+					m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+						Type:       "error",
+						UpdateType: mode.JobType(),
+						Detail:     fmt.Sprintf("%v gen dut meta failed, detail is: %v", mode.JobType(), err.Error()),
+					})
+
 					if unref != nil {
 						unref()
 					}
 					return err
 				}
-				logger.Info(uuid)
+				logger.Info("update UUID:", uuid)
 				m.updatePlatform.CreateJobPostMsgInfo(uuid, job.updateTyp)
 				systemErr := dut.CheckSystem(dut.PreCheck, nil) // 只是为了执行precheck的hook脚本
 				if systemErr != nil {
 					logger.Info(systemErr)
-					m.updatePlatform.PostStatusMessage(fmt.Sprintf("%v CheckSystem failed, detail is: %v", mode.JobType(), systemErr.Error()))
+
+					m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+						Type:       "error",
+						UpdateType: mode.JobType(),
+						Detail:     fmt.Sprintf("CheckSystem failed, detail is: %v", systemErr.Error()),
+					})
 					return systemErr
 				}
 				if !system.CheckInstallAddSize(mode) {
@@ -328,7 +406,12 @@ func (m *Manager) distUpgrade(sender dbus.Sender, mode system.UpdateType, needAd
 				systemErr := dut.CheckSystem(dut.MidCheck, nil)
 				if systemErr != nil {
 					logger.Info(systemErr)
-					m.updatePlatform.PostStatusMessage(fmt.Sprintf("%v CheckSystem failed, detail is: %v", mode.JobType(), systemErr.Error()))
+
+					m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+						Type:       "error",
+						UpdateType: mode.JobType(),
+						Detail:     fmt.Sprintf("%v CheckSystem failed, detail is: %v", mode.JobType(), systemErr.Error()),
+					})
 					return systemErr
 				}
 				if m.statusManager.abStatus == system.HasBackedUp {
@@ -524,8 +607,12 @@ func (m *Manager) preFailedHook(job *Job, mode system.UpdateType, uuid string) e
 				allErrMsg = append(allErrMsg, fmt.Sprintf("upgrade failed time is %v \n", time.Now()))
 				allErrMsg = append(allErrMsg, string(msg))
 			}
+			m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+				Type:       "error",
+				UpdateType: mode.JobType(),
+				Detail:     fmt.Sprintf("upgrade failed, detail is: %v; all error message is %v", job.Description, strings.Join(allErrMsg, "\n")),
+			})
 		}
-		m.updatePlatform.PostStatusMessage(fmt.Sprintf("%v upgrade failed, detail is: %v; all error message is %v", mode.JobType(), job.Description, strings.Join(allErrMsg, "\n")))
 	}()
 	m.statusManager.SetUpdateStatus(mode, system.UpgradeErr)
 	// 如果安装失败，那么需要将version文件一直缓存，防止下次检查更新时version版本变高
@@ -545,7 +632,11 @@ func (m *Manager) preUpgradeCmdSuccessHook(job *Job, needChangeGrub bool, mode s
 	}
 	m.statusManager.SetUpdateStatus(mode, system.Upgraded)
 	job.setPropProgress(1.00)
-	m.updatePlatform.PostStatusMessage(fmt.Sprintf("%v install package success，need reboot and check", mode))
+
+	m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+		Type:   "info",
+		Detail: fmt.Sprintf("%v install package success, need reboot and check", mode.JobType()),
+	})
 	return nil
 }
 
@@ -598,86 +689,18 @@ func (m *Manager) cancelAllUpdateJob() error {
 	return nil
 }
 
-// 生成meta.json和uuid 暂时不使用dut，使用apt
-func (m *Manager) prepareDutUpgrade(job *Job, mode system.UpdateType) (string, error) {
-	// 使用dut更新前的准备
-	var uuid string
-	var err error
-	{
-		job.option["--meta-cfg"] = system.DutOnlineMetaConfPath
-		var pkgMap map[string]system.PackageInfo
-		var removeMap map[string]system.PackageInfo
-		mode &= system.AllInstallUpdate
-		if mode == 0 {
-			return "", errors.New("invalid mode")
-		}
-
-		// m.allUpgradableInfoMu.Lock()
-		// pkgMap = m.mergePackagesByMode(mode, m.allUpgradableInfo)
-		// m.allUpgradableInfoMu.Unlock()
-		// m.allRemovePkgInfoMu.Lock()
-		// removeMap = m.mergePackagesByMode(mode, m.allRemovePkgInfo)
-		// m.allRemovePkgInfoMu.Unlock()
-
-		coreListMap := make(map[string]system.PackageInfo)
-		if m.coreList != nil && len(m.coreList) > 0 {
-			for _, pkgName := range m.coreList {
-				coreListMap[pkgName] = system.PackageInfo{
-					Name:    pkgName,
-					Version: "",
-					Need:    "skipversion",
-				}
-			}
-		} else {
-			loadCoreList := func() map[string]system.PackageInfo {
-				coreListMap := make(map[string]system.PackageInfo)
-				data, err := os.ReadFile(coreListVarPath)
-				if err != nil {
-					return nil
-				}
-				var pkgList PackageList
-				err = json.Unmarshal(data, &pkgList)
-				if err != nil {
-					return nil
-				}
-				for _, pkg := range pkgList.PkgList {
-					coreListMap[pkg.PkgName] = system.PackageInfo{
-						Name:    pkg.PkgName,
-						Version: "",
-						Need:    "skipversion",
-					}
-				}
-				return nil
-			}
-			coreListMap = loadCoreList()
-		}
-		uuid, err = dut.GenDutMetaFile(system.DutOnlineMetaConfPath,
-			system.LocalCachePath,
-			pkgMap,
-			coreListMap, nil, nil, removeMap,
-			m.updatePlatform.GetRules(), genRepoInfo(mode, system.OnlineListPath))
-
-		if err != nil {
-			logger.Warning(err)
-			return "", err
-		}
-	}
-	return uuid, nil
-}
-
 // 生成meta.json和uuid
 func (m *Manager) prepareAptCheck(mode system.UpdateType) (string, error) {
 	var uuid string
 	var err error
-	// pkgMap repo和system.LocalCachePath都是占位用，没有起到真正的作用
-	pkgMap := make(map[string]system.PackageInfo)
+	// repo和system.LocalCachePath都是占位用，没有起到真正的作用
 	var repo []dut.RepoInfo
 
 	repo = genRepoInfo(mode, system.OnlineListPath)
 
 	// coreList 生成
 	coreListMap := make(map[string]system.PackageInfo)
-	if m.coreList != nil && len(m.coreList) > 0 {
+	if len(m.coreList) > 0 {
 		for _, pkgName := range m.coreList {
 			coreListMap[pkgName] = system.PackageInfo{
 				Name:    pkgName,
@@ -714,11 +737,9 @@ func (m *Manager) prepareAptCheck(mode system.UpdateType) (string, error) {
 		if mode == 0 {
 			return "", errors.New("invalid mode")
 		}
+		m.updatePlatform.PrepareCheckScripts()
 		uuid, err = dut.GenDutMetaFile(system.DutOnlineMetaConfPath,
-			system.LocalCachePath,
-			pkgMap,
-			coreListMap, nil, nil, nil,
-			m.updatePlatform.GetRules(), repo)
+			system.LocalCachePath, coreListMap, repo)
 		if err != nil {
 			logger.Warning(err)
 			return "", err
@@ -727,45 +748,6 @@ func (m *Manager) prepareAptCheck(mode system.UpdateType) (string, error) {
 	return uuid, err
 }
 
-func (m *Manager) mergePackagesByMode(mode system.UpdateType, needMergePkgMap map[system.UpdateType]map[string]system.PackageInfo) map[string]system.PackageInfo {
-	typeArray := system.UpdateTypeBitToArray(mode)
-	var res map[string]system.PackageInfo
-	if len(typeArray) == 0 {
-		return nil
-	}
-	jsonStr, err := json.Marshal(needMergePkgMap[typeArray[0]])
-	if err != nil {
-		logger.Warning(err)
-		return nil
-	}
-	err = json.Unmarshal(jsonStr, &res)
-	if err != nil {
-		logger.Warning(err)
-		return nil
-	}
-
-	if len(typeArray) == 1 {
-		return res
-	}
-
-	typeArray = typeArray[1:]
-	for _, typ := range typeArray {
-		for name, newInfo := range needMergePkgMap[typ] {
-			originInfo, ok := res[name]
-			if ok {
-				// 当两个仓库存在相同包，留版本高的包
-				if compareVersionsGe(newInfo.Version, originInfo.Version) {
-					res[name] = newInfo
-				}
-			} else {
-				// 不存在时直接添加
-				res[name] = newInfo
-			}
-		}
-	}
-	return res
-}
-
 // 生成repo信息
 func genRepoInfo(typ system.UpdateType, listPath string) []dut.RepoInfo {
 	var repoInfos []dut.RepoInfo
